@@ -69,6 +69,13 @@ do
   temperatura=`cat /sys/class/power_supply/bq27200-0/temp`
   #echo "temp: " $temperatura
 
+# v47
+  lunghezza=${#temperatura}
+  if [ $lunghezza == 3 ]
+  then
+     temperatura=`expr $temperatura / 10`
+  fi
+# v47
 
   # supera limite
   if [ $temperatura_max -le $temperatura ] 
